@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 import logging
@@ -82,6 +81,9 @@ FILTERS = [
     "filters:gifv(mp4)",
     "filters:max_age(600)",
     "filters:upscale()",
+    "filters:format(avif)",
+    "filters:format(heic)",
+    "filters:format(heif)",
     # one big filter 4-line string
     "filters:curve([(0,0),(255,255)],[(0,50),(16,51),(32,69),"
     "(58,85),(92,120),(128,170),(140,186),(167,225),"  # NOQA
@@ -98,6 +100,7 @@ ORIGINAL_IMAGES_BASE = [
     "rgba.png",
     "grayscale.jpg",
     "16bit.png",
+    "thumbor-exif.png",
 ]
 
 ORIGINAL_IMAGES_GIF_WEBP = [
