@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -11,6 +10,7 @@
 import unicodedata
 from io import BytesIO
 from os.path import exists
+from unittest import skipUnless
 
 from PIL import Image
 from preggy import create_assertions
@@ -20,6 +20,39 @@ from thumbor.testing import FilterTestCase as ThumborFilterTestCase
 from thumbor.testing import TestCase as ThumborTestCase
 from thumbor.testing import get_ssim
 
+try:
+    from PIL import _avif  # noqa pylint: disable=ungrouped-imports
+except ImportError:
+    try:
+        from pillow_avif import _avif
+    except ImportError:
+        _avif = None
+
+try:
+    from pillow_heif import HeifImagePlugin
+except ImportError:
+    HeifImagePlugin = None
+
+AVIF_AVAILABLE = _avif is not None
+HEIF_AVAILABLE = HeifImagePlugin is not None
+
+skip_unless_avif = skipUnless(
+    AVIF_AVAILABLE,
+    "AVIF format support not found. Skipping AVIF tests.",
+)
+
+skip_unless_heif = skipUnless(
+    HEIF_AVAILABLE,
+    "HEIF format support not found. Skipping HEIF tests.",
+)
+
+
+def skip_unless_avif_encoder(codec_name):
+    return skipUnless(
+        _avif and _avif.encoder_codec_available(codec_name),
+        f"{codec_name} encode not available",
+    )
+
 
 class TestCase(ThumborTestCase):
     pass
@@ -77,6 +110,18 @@ def to_be_webp(topic):
     return image.format.lower() == "webp"
 
 
+@create_assertions
+def to_be_avif(topic):
+    image = Image.open(BytesIO(topic))
+    return image.format.lower() == "avif"
+
+
+@create_assertions
+def to_be_heif(topic):
+    image = Image.open(BytesIO(topic))
+    return image.format.lower() == "heif"
+
+
 @create_assertions
 def to_be_png(topic):
     image = Image.open(BytesIO(topic))
