@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -61,6 +60,7 @@ class BaseEngineTestCase(TestCase):
     def setUp(self):
         self.image = ((1, 2), (3, 4))
         self.context = self.get_context()
+        self.context.request = mock.MagicMock(width=0, height=0)
         self.engine = BaseEngine(self.context)
         self.engine.flip_horizontally = mock.MagicMock()
         self.engine.flip_horizontally.side_effect = self.flip_horizontally
@@ -162,6 +162,18 @@ class BaseEngineTestCase(TestCase):
         mime = self.engine.get_mimetype(buffer)
         expect(mime).to_equal("image/svg+xml")
 
+    def test_can_identify_avif(self):
+        with open(join(STORAGE_PATH, "image.avif"), "rb") as image:
+            buffer = image.read()
+        mime = self.engine.get_mimetype(buffer)
+        expect(mime).to_equal("image/avif")
+
+    def test_can_identify_heic(self):
+        with open(join(STORAGE_PATH, "image.heic"), "rb") as image:
+            buffer = image.read()
+        mime = self.engine.get_mimetype(buffer)
+        expect(mime).to_equal("image/heif")
+
     def test_convert_svg_already_converted_to_png(self):
         svg_buffer = """<svg width="10px" height="20px" viewBox="0 0 10 20"
                     xmlns="http://www.w3.org/2000/svg">
