@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -16,18 +15,18 @@ from tests.base import FilterTestCase
 
 
 class BackgroundColorFilterTestCase(FilterTestCase):
+    def config_context(self, context):
+        context.request.fit_in = True
+        context.request.width = 300
+        context.request.height = 300
+
     @gen_test
     async def test_background_color_filter_with_fixed_color(self):
-        def config_context(context):
-            context.request.fit_in = True
-            context.request.width = 300
-            context.request.height = 300
-
         image = await self.get_filtered(
             "PNG_transparency_demonstration_1.png",
             "thumbor.filters.background_color",
             "background_color(blue)",
-            config_context=config_context,
+            config_context=self.config_context,
         )
 
         expected = self.get_fixture(
@@ -36,3 +35,19 @@ class BackgroundColorFilterTestCase(FilterTestCase):
 
         ssim = self.get_ssim(image, expected)
         expect(ssim).to_be_greater_than(0.97)
+
+    @gen_test
+    async def test_background_color_filter_with_auto_color(self):
+        image = await self.get_filtered(
+            "PNG_transparency_demonstration_1.png",
+            "thumbor.filters.background_color",
+            "background_color(auto)",
+            config_context=self.config_context,
+        )
+
+        expected = self.get_fixture(
+            "PNG_transparency_demonstration_1_auto.png"
+        )
+
+        ssim = self.get_ssim(image, expected)
+        expect(ssim).to_be_greater_than(0.97)
