@@ -2,5 +2,5 @@ class ErrorHandler:
     def __init__(self, config):
         self.config = config
 
-    def handle_error(context, handler, exception):
+    def handle_error(self, context, handler, exception):
         pass
