@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -8,17 +7,16 @@
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com thumbor@googlegroups.com
 
-import os
 from io import BytesIO
-from subprocess import PIPE, Popen
-from tempfile import mkstemp
 
+import piexif
+from JpegIPTC import JpegIPTC
 from PIL import Image, ImageDraw, ImageFile, ImageSequence, JpegImagePlugin
 from PIL import features as pillow_features
 
 from thumbor.engines import BaseEngine
-from thumbor.engines.extensions.pil import GifWriter
-from thumbor.utils import deprecated, logger
+from thumbor.filters.fill import Filter
+from thumbor.utils import deprecated, ensure_srgb, get_color_space, logger
 
 try:
     from thumbor.ext.filters import _composite
@@ -27,6 +25,23 @@ try:
 except ImportError:
     FILTERS_AVAILABLE = False
 
+try:
+    from PIL import _avif  # pylint: disable=ungrouped-imports
+except ImportError:
+    try:
+        from pillow_avif import _avif
+    except ImportError:
+        _avif = None
+
+try:
+    from pillow_heif import HeifImagePlugin
+except ImportError:
+    HeifImagePlugin = None
+
+HAVE_AVIF = _avif is not None
+HAVE_HEIF = HeifImagePlugin is not None
+
+
 FORMATS = {
     ".tif": "PNG",  # serve tif as png
     ".jpg": "JPEG",
@@ -34,8 +49,17 @@ FORMATS = {
     ".gif": "GIF",
     ".png": "PNG",
     ".webp": "WEBP",
+    ".avif": "AVIF",
+    ".heic": "HEIF",
+    ".heif": "HEIF",
 }
 
+KEEP_EXIF_COPYRIGHT_TAGS = [
+    piexif.ImageIFD.Artist,
+    piexif.ImageIFD.Copyright,
+    piexif.ImageIFD.DateTime,
+]
+
 ImageFile.MAXBLOCK = 2**25
 ImageFile.LOAD_TRUNCATED_IMAGES = True
 
@@ -52,6 +76,7 @@ class Engine(BaseEngine):
         self.qtables = None
         self.original_mode = None
         self.exif = None
+        self.iptc = None
 
         try:
             if self.context.config.MAX_PIXELS is None or int(
@@ -66,6 +91,10 @@ class Engine(BaseEngine):
     def gen_image(self, size, color):
         if color == "transparent":
             color = None
+        elif color == "auto":
+            color = Filter.get_median_color(self.context.modules)
+            color = f"#{color}"
+
         img = Image.new("RGBA", size, color)
 
         return img
@@ -81,10 +110,16 @@ class Engine(BaseEngine):
         self.exif = img.info.get("exif")
         self.original_mode = img.mode
 
-        self.subsampling = JpegImagePlugin.get_sampling(img)
+        if self.context.config.PRESERVE_IPTC_INFO:
+            jpegiptc_object = JpegIPTC()
+            jpegiptc_object.load_from_binarydata(buffer)
+            self.iptc = jpegiptc_object.get_raw_iptc()
+
+        if hasattr(img, "layer"):
+            self.subsampling = JpegImagePlugin.get_sampling(img)
+            if self.subsampling == -1:  # n/a for this file
+                self.subsampling = None
 
-        if self.subsampling == -1:  # n/a for this file
-            self.subsampling = None
         self.qtables = getattr(img, "quantization", None)
 
         if (
@@ -102,6 +137,26 @@ class Engine(BaseEngine):
 
         return img
 
+    def get_exif_copyright(self):
+        try:
+            exifs = piexif.load(self.image.info.get("exif"))
+        except Exception:
+            return self.image.info.get("exif")
+
+        return self.extract_copyright_from_exif(exifs)
+
+    def extract_copyright_from_exif(self, exifs):
+        copyright_exif = {}
+
+        if exifs is None or "0th" not in exifs or exifs["0th"] is None:
+            return None
+
+        for copyright_tag in KEEP_EXIF_COPYRIGHT_TAGS:
+            if copyright_tag in exifs["0th"]:
+                copyright_exif[copyright_tag] = exifs["0th"][copyright_tag]
+
+        return piexif.dump({"0th": copyright_exif})
+
     def get_resize_filter(self):
         config = self.context.config
         resample = (
@@ -111,14 +166,14 @@ class Engine(BaseEngine):
         )
 
         available = {
-            "LANCZOS": Image.LANCZOS,
-            "NEAREST": Image.NEAREST,
-            "BILINEAR": Image.BILINEAR,
-            "BICUBIC": Image.BICUBIC,
-            "HAMMING": Image.HAMMING,
+            "LANCZOS": Image.Resampling.LANCZOS,
+            "NEAREST": Image.Resampling.NEAREST,
+            "BILINEAR": Image.Resampling.BILINEAR,
+            "BICUBIC": Image.Resampling.BICUBIC,
+            "HAMMING": Image.Resampling.HAMMING,
         }
 
-        return available.get(resample.upper(), Image.LANCZOS)
+        return available.get(resample.upper(), Image.Resampling.LANCZOS)
 
     def draw_rectangle(self, x, y, width, height):
         # Nasty retry if the image is loaded for the first time and it's truncated
@@ -163,19 +218,19 @@ class Engine(BaseEngine):
         # PIL rotates counter clockwise
 
         if degrees == 90:
-            self.image = self.image.transpose(Image.ROTATE_90)
+            self.image = self.image.transpose(Image.Transpose.ROTATE_90)
         elif degrees == 180:
-            self.image = self.image.transpose(Image.ROTATE_180)
+            self.image = self.image.transpose(Image.Transpose.ROTATE_180)
         elif degrees == 270:
-            self.image = self.image.transpose(Image.ROTATE_270)
+            self.image = self.image.transpose(Image.Transpose.ROTATE_270)
         else:
             self.image = self.image.rotate(degrees, expand=1)
 
     def flip_vertically(self):
-        self.image = self.image.transpose(Image.FLIP_TOP_BOTTOM)
+        self.image = self.image.transpose(Image.Transpose.FLIP_TOP_BOTTOM)
 
     def flip_horizontally(self):
-        self.image = self.image.transpose(Image.FLIP_LEFT_RIGHT)
+        self.image = self.image.transpose(Image.Transpose.FLIP_LEFT_RIGHT)
 
     def get_default_extension(self):
         # extension is not present => force JPEG or PNG
@@ -209,7 +264,7 @@ class Engine(BaseEngine):
                 # libimagequant might not be enabled on compile time
                 # but it's better than default octree for RGBA images
                 quantize_method = (
-                    Image.LIBIMAGEQUANT
+                    Image.Quantize.LIBIMAGEQUANT
                     if pillow_features.check("libimagequant")
                     else None
                 )
@@ -217,6 +272,20 @@ class Engine(BaseEngine):
 
         ext = requested_extension or self.get_default_extension()
 
+        if ext in (".heic", ".heif") and not HAVE_HEIF:
+            logger.warning(
+                "[PILEngine] HEIF encoding unavailable, defaulting to %s",
+                self.extension,
+            )
+            ext = self.extension
+
+        if ext == ".avif" and not HAVE_AVIF:
+            logger.warning(
+                "[PILEngine] AVIF encoding unavailable, defaulting to %s",
+                self.extension,
+            )
+            ext = self.extension
+
         options = {"quality": quality}
 
         if ext in (".jpg", ".jpeg"):
@@ -267,16 +336,67 @@ class Engine(BaseEngine):
             ext == ".png"
             and self.context.config.PNG_COMPRESSION_LEVEL is not None
         ):
-            options[
-                "compress_level"
-            ] = self.context.config.PNG_COMPRESSION_LEVEL
+            options["compress_level"] = (
+                self.context.config.PNG_COMPRESSION_LEVEL
+            )
 
         if options["quality"] is None:
             options["quality"] = self.context.config.QUALITY
 
+        if ext == ".avif":
+            options["codec"] = self.context.config.AVIF_CODEC
+            if self.context.config.AVIF_SPEED:
+                options["speed"] = self.context.config.AVIF_SPEED
+
+            if options["codec"] == "svt":
+                width, height = self.size
+                # SVT-AV1 has limits on min and max image dimension. If the
+                # image falls outside of those, use AVIF_CODEC_FALLBACK
+                if not 64 <= width <= 4096 or not 64 <= height <= 4096:
+                    options["codec"] = self.context.config.AVIF_CODEC_FALLBACK
+                elif width % 2 or height % 2:
+                    # SVT-AV1 requires width and height to be divisible by two
+                    width = (width // 2) * 2
+                    height = (height // 2) * 2
+                    self.crop(0, 0, width, height)
+
+            if options["quality"] == "keep":
+                options.pop("quality")
+
+            if self.image.mode not in ["RGB", "RGBA"]:
+                if self.image.mode == "P":
+                    mode = "RGBA"
+                else:
+                    mode = "RGBA" if self.image.mode[-1] == "A" else "RGB"
+                self.image = self.image.convert(mode)
+
+            # Some AVIF decoders (most notably the one in Chrome) do not
+            # display AVIF images if they have an embedded ICC profile with a
+            # color space that doesn't match the image's mode (e.g. if the
+            # mode is RGB but the profile is CMYK or GRAY).
+            #
+            # To address this issue we transform non-sRGB ICC profiles to sRGB
+            # if we're encoding to AVIF.
+            color_space = get_color_space(self.image)
+            if color_space not in ("RGB", None):
+                srgb_image = ensure_srgb(
+                    self.image, srgb_profile=self.context.config.SRGB_PROFILE
+                )
+                if srgb_image:
+                    self.image = srgb_image
+                    self.icc_profile = srgb_image.info.get("icc_profile")
+
         if self.icc_profile is not None:
             options["icc_profile"] = self.icc_profile
 
+        if (
+            self.context.config.PRESERVE_EXIF_COPYRIGHT_INFO is True
+            and self.image.info.get("exif") is not None
+        ):
+            exif_copyright = self.get_exif_copyright()
+            if exif_copyright is not None:
+                options["exif"] = exif_copyright
+
         if self.context.config.PRESERVE_EXIF_INFO:
             if self.exif is not None:
                 options["exif"] = self.exif
@@ -295,7 +415,11 @@ class Engine(BaseEngine):
                         mode = "RGBA" if self.image.mode[-1] == "A" else "RGB"
                     self.image = self.image.convert(mode)
 
-            if ext in [".png", ".gif"] and self.image.mode == "CMYK":
+            if (
+                ext in [".png", ".gif", ".heic", ".heif"]
+                and self.image.mode == "CMYK"
+            ):
+                # 26.10.22: remove ".heic, .heif" in a month(when pillow_heif get updated)
                 self.image = self.image.convert("RGBA")
 
             self.image.format = FORMATS.get(
@@ -312,53 +436,30 @@ class Engine(BaseEngine):
         img_buffer.close()
         self.extension = ext
 
+        if self.context.config.PRESERVE_IPTC_INFO:
+            jpegiptc_object_d = JpegIPTC()
+            jpegiptc_object_d.load_from_binarydata(results)
+            jpegiptc_object_d.set_raw_iptc(self.iptc)
+            newresults = jpegiptc_object_d.dump()
+            if newresults is not None:
+                results = newresults
+
         return results
 
     def read_multiple(self, images, extension=None):
-        gif_writer = GifWriter()
-        img_buffer = BytesIO()
-
-        duration = []
-        converted_images = []
-        coordinates = []
-        dispose = []
-
-        for image in images:
-            duration.append(image.info.get("duration", 80) / 1000)
-            converted_images.append(image.convert("RGB"))
-            coordinates.append((0, 0))
-            dispose.append(1)
-
-        loop = int(self.image.info.get("loop", 1))
-
-        images = gif_writer.convertImagesToPIL(converted_images, False, None)
-        gif_writer.writeGifToFile(
-            img_buffer, images, duration, loop, coordinates, dispose
+        self.image.format = FORMATS.get(
+            extension or self.extension, FORMATS[self.get_default_extension()]
         )
-
-        results = img_buffer.getvalue()
-        img_buffer.close()
-
-        tmp_fd, tmp_file_path = mkstemp()
-        temp_file = os.fdopen(tmp_fd, "wb")
-        temp_file.write(results)
-        temp_file.close()
-
-        command = ["gifsicle", "--colors", "256", tmp_file_path]
-
-        popen = Popen(  # pylint: disable=consider-using-with
-            command, stdout=PIPE
-        )
-        pipe = popen.stdout
-        pipe_output = pipe.read()
-        pipe.close()
-
-        if popen.wait() == 0:
-            results = pipe_output
-
-        os.remove(tmp_file_path)
-
-        return results
+        with BytesIO() as img_buffer:
+            images[0].save(
+                img_buffer,
+                self.image.format,
+                save_all=True,
+                append_images=images[1:],
+                duration=[im.info.get("duration", 80) / 1000 for im in images],
+                loop=int(self.image.info.get("loop", 1)),
+            )
+            return img_buffer.getvalue()
 
     @deprecated("Use image_data_as_rgb instead.")
     def get_image_data(self):
@@ -414,6 +515,12 @@ class Engine(BaseEngine):
 
         return has_transparency
 
+    def avif_enabled(self):
+        return HAVE_AVIF
+
+    def heif_enabled(self):
+        return HAVE_HEIF
+
     def paste(self, other_engine, pos, merge=True):
         if merge and not FILTERS_AVAILABLE:
             raise RuntimeError(
