@@ -3,16 +3,17 @@
 static PyObject*
 _alpha_apply(PyObject *self, PyObject *args)
 {
-    PyObject *buffer = NULL, *delta = NULL, *image_mode = NULL;
 
-    if (!PyArg_UnpackTuple(args, "apply", 3, 3, &image_mode, &delta, &buffer)) {
+    PyObject *buffer = NULL;
+    char *image_mode_str;
+    int delta_int;
+
+    if (!PyArg_ParseTuple(args, "siO:apply", &image_mode_str, &delta_int, &buffer)) {
         return NULL;
     }
 
-    char *image_mode_str = PyString_AsString(image_mode);
-    Py_ssize_t size = PyString_Size(buffer);
-    unsigned char *ptr = (unsigned char *) PyString_AsString(buffer);
-    int delta_int = (int) PyInt_AsLong(delta);
+    Py_ssize_t size = PyBytes_Size(buffer);
+    unsigned char *ptr = (unsigned char *) PyBytes_AsString(buffer);
 
     int num_bytes = bytes_per_pixel(image_mode_str),
         alpha_idx = rgb_order(image_mode_str, 'A');
