@@ -3,15 +3,15 @@
 static PyObject*
 _fill_apply(PyObject *self, PyObject *args)
 {
-    PyObject *buffer = NULL, *image_mode = NULL;
+    PyObject *buffer = NULL;
+    char *image_mode_str;
 
-    if (!PyArg_UnpackTuple(args, "apply", 2, 2, &image_mode, &buffer)) {
+    if (!PyArg_ParseTuple(args, "sO:apply", &image_mode_str, &buffer)) {
         return NULL;
     }
 
-    char *image_mode_str = PyString_AsString(image_mode);
-    Py_ssize_t size = PyString_Size(buffer);
-    unsigned char *ptr = (unsigned char *) PyString_AsString(buffer);
+    Py_ssize_t size = PyBytes_Size(buffer);
+    unsigned char *ptr = (unsigned char *) PyBytes_AsString(buffer);
 
     int num_bytes = bytes_per_pixel(image_mode_str);
     int r_idx = rgb_order(image_mode_str, 'R'),
