@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 # thumbor imaging service
 # https://github.com/thumbor/thumbor/wiki
@@ -9,5 +8,5 @@ from thumbor.filters import BaseFilter, filter_method
 
 class Filter(BaseFilter):
     @filter_method(BaseFilter.Boolean)
-    def autojpg(self, enabled=True):
+    async def autojpg(self, enabled=True):
         self.context.request.auto_png_to_jpg = enabled
