@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -11,7 +10,7 @@
 from thumbor.filters import BaseFilter, filter_method
 from thumbor.utils import logger
 
-ALLOWED_FORMATS = ["png", "jpeg", "jpg", "gif", "webp"]
+ALLOWED_FORMATS = ["png", "jpeg", "jpg", "gif", "webp", "avif", "heic", "heif"]
 
 
 class Filter(BaseFilter):
