@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -20,6 +19,7 @@ class Filter(BaseFilter):
     async def no_upscale(self):
         image_size = self.context.request.engine.size
         orientation = self.context.request.engine.get_orientation()
+
         if self.context.config.RESPECT_ORIENTATION and orientation in [
             5,
             6,
@@ -27,7 +27,9 @@ class Filter(BaseFilter):
             8,
         ]:
             image_size = (image_size[1], image_size[0])
-        if self.context.request.width > image_size[0]:
-            self.context.request.width = image_size[0]
-        if self.context.request.height > image_size[1]:
-            self.context.request.height = image_size[1]
+        self.context.request.width = min(
+            self.context.request.width, image_size[0]
+        )
+        self.context.request.height = min(
+            self.context.request.height, image_size[1]
+        )
