@@ -7,12 +7,12 @@
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com thumbor@googlegroups.com
 
-from thumbor.filters import BaseFilter, filter_method, PHASE_PRE_LOAD
+from thumbor.filters import PHASE_PRE_LOAD, BaseFilter, filter_method
 
 
 class Filter(BaseFilter):
     phase = PHASE_PRE_LOAD
 
     @filter_method()
-    def stretch(self):
+    async def stretch(self):
         self.context.request.stretch = True
