@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -33,11 +32,11 @@ from thumbor.utils import CONTENT_TYPE, EXTENSION, logger
 HTTP_DATE_FMT = "%a, %d %b %Y %H:%M:%S GMT"
 
 # Handlers should not override __init__ pylint: disable=attribute-defined-outside-init,arguments-differ
-# pylint: disable=broad-except,abstract-method,too-many-branches,too-many-return-statements,too-many-statements
+# pylint: disable=broad-except,abstract-method,too-many-branches,too-many-return-statements,too-many-statements,too-many-lines
 
 
 class FetchResult:  # Data Object pylint: disable=too-few-public-methods
-    def __init__(
+    def __init__(  # pylint: disable=too-many-positional-arguments
         self,
         normalized=False,
         buffer=None,
@@ -126,11 +125,13 @@ class BaseHandler(tornado.web.RequestHandler):
         ).total_seconds() * 1000
 
         if self.context.request.smart:
-            self.context.metrics.incr("response.smart")
-            self.context.metrics.timing("response.smart", total_time)
+            self.context.metrics.incr("response.smart.count")
+            self.context.metrics.timing("response.smart.latency", total_time)
         else:
-            self.context.metrics.incr("response.none_smart")
-            self.context.metrics.timing("response.none_smart", total_time)
+            self.context.metrics.incr("response.none_smart.count")
+            self.context.metrics.timing(
+                "response.none_smart.latency", total_time
+            )
 
         should_store = (
             self.context.config.RESULT_STORAGE_STORES_UNSAFE
@@ -285,6 +286,9 @@ class BaseHandler(tornado.web.RequestHandler):
 
                 return
 
+        if not normalized:
+            normalized = engine.normalize()
+
         self.context.transformer = Transformer(self.context)
 
         await self.filters_runner.apply_filters(
@@ -293,9 +297,9 @@ class BaseHandler(tornado.web.RequestHandler):
         self.normalize_crops(normalized, req, engine)
 
         if req.meta:
-            self.context.transformer.engine = (
-                self.context.request.engine
-            ) = JSONEngine(engine, req.image_url, req.meta_callback)
+            self.context.transformer.engine = self.context.request.engine = (
+                JSONEngine(engine, req.image_url, req.meta_callback)
+            )
 
         await self.context.transformer.transform()
         await self.after_transform()
@@ -372,12 +376,12 @@ class BaseHandler(tornado.web.RequestHandler):
             block = data[i : i + 1]  # NOQA
             i += 1
 
-            if block == b"\x3B":
+            if block == b"\x3b":
                 break
 
             if block == b"\x21":
                 i += 1
-            elif block == b"\x2C":
+            elif block == b"\x2c":
                 frames += 1
                 i += 8
                 i = skip_color_table(i + 1, data[i])
@@ -410,6 +414,69 @@ class BaseHandler(tornado.web.RequestHandler):
 
         return False
 
+    def accepts_mime_type(self, mimetype=""):
+        if self.context.request and self.context.request.headers:
+            return mimetype in self.context.request.headers.get("Accept", "")
+
+        return False
+
+    def can_auto_convert_to_avif(self):
+        auto_avif = self.context.config.AUTO_AVIF
+        accepts_avif = self.accepts_mime_type("image/avif")
+
+        if (
+            auto_avif is True
+            and accepts_avif is True
+            and not self.context.request.engine.is_multiple()
+        ):
+            return self.context.request.engine.can_auto_convert_to_avif()
+
+        return False
+
+    def can_auto_convert_to_heif(self):
+        auto_heif = self.context.config.AUTO_HEIF
+        accepts_heif = self.accepts_mime_type("image/heif")
+
+        if (
+            auto_heif
+            and accepts_heif
+            and not self.context.request.engine.is_multiple()
+        ):
+            return self.context.request.engine.can_auto_convert_to_heif()
+
+        return False
+
+    def can_auto_convert_to_jpg(self):
+        auto_jpg = self.context.config.AUTO_JPG
+        accepts_jpg = (
+            self.accepts_mime_type("*/*")
+            or self.accepts_mime_type("image/jpg")
+            or self.accepts_mime_type("image/jpeg")
+        )
+
+        if (
+            auto_jpg
+            and accepts_jpg
+            and not self.context.request.engine.is_multiple()
+            and not self.context.request.engine.has_transparency()
+        ):
+            return True
+
+        return False
+
+    def can_auto_convert_to_png(self):
+        auto_png = self.context.config.AUTO_PNG
+        accepts_png = self.accepts_mime_type("image/png")
+
+        if (
+            auto_png
+            and accepts_png
+            and not self.context.request.engine.is_multiple()
+        ):
+            return True
+
+        return False
+
     def define_image_type(self, context, result):
         if result is not None:
             if isinstance(result, ResultStorageResult):
@@ -435,12 +502,30 @@ class BaseHandler(tornado.web.RequestHandler):
             logger.debug(
                 "Image format set by AUTO_WEBP as %s.", image_extension
             )
-        elif self.can_auto_convert_png_to_jpg():
+        elif self.can_auto_convert_to_avif():
+            image_extension = ".avif"
+            logger.debug(
+                "Image format set by AUTO_AVIF as %s.", image_extension
+            )
+        elif (
+            self.can_auto_convert_png_to_jpg()
+            or self.can_auto_convert_to_jpg()
+        ):
             image_extension = ".jpg"
             logger.debug(
-                "Image format set by AUTO_PNG_TO_JPG as %s.",
+                "Image format set by AUTO_PNG_TO_JPG or AUTO_JPG as %s.",
                 image_extension,
             )
+        elif self.can_auto_convert_to_heif():
+            image_extension = ".heif"
+            logger.debug(
+                "Image format set by AUTO_HEIF as %s.", image_extension
+            )
+        elif self.can_auto_convert_to_png():
+            image_extension = ".png"
+            logger.debug(
+                "Image format set by AUTO_PNG as %s.", image_extension
+            )
         else:
             image_extension = context.request.engine.extension
             logger.debug(
@@ -480,6 +565,15 @@ class BaseHandler(tornado.web.RequestHandler):
                 and self.context.config.WEBP_QUALITY is not None
             ):
                 quality = self.context.config.get("WEBP_QUALITY")
+            elif (
+                image_extension == ".avif"
+                and self.context.config.AVIF_QUALITY is not None
+            ):
+                quality = self.context.config.AVIF_QUALITY
+            elif image_extension in (".heif", ".heic"):
+                quality = self.context.config.HEIF_QUALITY
+                if quality is None:
+                    quality = 75
             else:
                 quality = self.context.config.QUALITY
 
@@ -570,17 +664,30 @@ class BaseHandler(tornado.web.RequestHandler):
             logger.exception("[BaseHander.finish_request] %s", error)
             self._error(500, f"Error while trying to fetch the image: {error}")
 
+            if self.context.config.USE_CUSTOM_ERROR_HANDLING:
+                self.context.modules.importer.error_handler.handle_error(
+                    context=self.context,
+                    handler=self.context.request_handler,
+                    exception=sys.exc_info(),
+                )
+
             return
 
         (results, content_type) = result
         await self._write_results_to_client(results, content_type)
 
         if should_store:
+            results = self._ensure_bytes(results)
             await self._store_results(result_storage, metrics, results)
 
         # can't cleanup before storing results as the storage requires context
         self._cleanup()
 
+    def _ensure_bytes(self, results):
+        if isinstance(results, str):
+            return results.encode()
+        return results
+
     def _cleanup(self):
         self.context.request_handler = None
 
@@ -631,7 +738,11 @@ class BaseHandler(tornado.web.RequestHandler):
             buffer = results
 
         # auto-convert configured?
-        should_vary = self.context.config.AUTO_WEBP
+        should_vary = (
+            self.context.config.AUTO_WEBP
+            or self.context.config.AUTO_AVIF
+            or self.context.config.AUTO_HEIF
+        )
         # we have image (not video)
         should_vary = should_vary and content_type.startswith("image/")
         # output format is not requested via format filter
@@ -720,7 +831,7 @@ class BaseHandler(tornado.web.RequestHandler):
         return prev_result
 
     @classmethod
-    def translate_crop_coordinates(
+    def translate_crop_coordinates(  # pylint: disable=too-many-positional-arguments
         cls,
         original_width,
         original_height,
@@ -731,7 +842,6 @@ class BaseHandler(tornado.web.RequestHandler):
         crop_right,
         crop_bottom,
     ):
-
         if original_width == width and original_height == height:
             return None
 
@@ -882,10 +992,10 @@ class BaseHandler(tornado.web.RequestHandler):
     async def get_blacklist_contents(self):
         filename = "blacklist.txt"
 
-        exists = await (self.context.modules.storage.exists(filename))
+        exists = await self.context.modules.storage.exists(filename)
 
         if exists:
-            blacklist = await (self.context.modules.storage.get(filename))
+            blacklist = await self.context.modules.storage.get(filename)
 
             return blacklist.decode()
 
