@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -40,7 +39,7 @@ class FocalPoint:
             origin=values.get("origin", "alignment"),
         )
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-positional-arguments
         self,
         x,  # pylint: disable=invalid-name
         y,  # pylint: disable=invalid-name
@@ -57,7 +56,7 @@ class FocalPoint:
         self.origin = origin
 
     @classmethod
-    def from_square(
+    def from_square(  # pylint: disable=too-many-positional-arguments
         cls, x, y, width, height, origin="detection"
     ):  # pylint: disable=invalid-name
         center_x = x + width // 2
