@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # thumbor imaging service
@@ -34,9 +33,9 @@ class Storage(BaseStorage):
                 item_value=self.context.config.MIXED_STORAGE_FILE_STORAGE,
                 class_name="Storage",
             )
-            self.file_storage = (
-                self.context.modules.file_storage
-            ) = self.context.modules.importer.file_storage(self.context)
+            self.file_storage = self.context.modules.file_storage = (
+                self.context.modules.importer.file_storage(self.context)
+            )
 
     def _init_crypto_storage(self):
         if self.crypto_storage is None:
@@ -45,9 +44,9 @@ class Storage(BaseStorage):
                 item_value=self.context.config.MIXED_STORAGE_CRYPTO_STORAGE,
                 class_name="Storage",
             )
-            self.crypto_storage = (
-                self.context.modules.crypto_storage
-            ) = self.context.modules.importer.crypto_storage(self.context)
+            self.crypto_storage = self.context.modules.crypto_storage = (
+                self.context.modules.importer.crypto_storage(self.context)
+            )
 
     def _init_detector_storage(self):
         if self.detector_storage is None:
@@ -56,9 +55,9 @@ class Storage(BaseStorage):
                 item_value=self.context.config.MIXED_STORAGE_DETECTOR_STORAGE,
                 class_name="Storage",
             )
-            self.detector_storage = (
-                self.context.modules.detector_storage
-            ) = self.context.modules.importer.detector_storage(self.context)
+            self.detector_storage = self.context.modules.detector_storage = (
+                self.context.modules.importer.detector_storage(self.context)
+            )
 
     async def put(self, path, file_bytes):
         self._init_file_storage()
@@ -89,7 +88,7 @@ class Storage(BaseStorage):
 
     async def exists(self, path):
         self._init_file_storage()
-        result = await (self.file_storage.exists(path))
+        result = await self.file_storage.exists(path)
         return result
 
     def resolve_original_photo_path(self, request, filename):
